<?php
/**
 * Swimming Pool Theme Customizer
 *
 * @package Swimming Pool
 */

get_template_part('/inc/select/category-dropdown-custom-control');

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function swimming_pool_customize_register( $wp_customize ) {

	function swimming_pool_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	}

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	$wp_customize->add_setting('swimming_pool_title_enable',array(
		'default' => true,
		'sanitize_callback' => 'swimming_pool_sanitize_checkbox',
	));
	$wp_customize->add_control( 'swimming_pool_title_enable', array(
	   'settings' => 'swimming_pool_title_enable',
	   'section'   => 'title_tagline',
	   'label'     => __('Enable Site Title','swimming-pool'),
	   'type'      => 'checkbox'
	));

	$wp_customize->add_setting('swimming_pool_tagline_enable',array(
		'default' => true,
		'sanitize_callback' => 'swimming_pool_sanitize_checkbox',
	));
	$wp_customize->add_control( 'swimming_pool_tagline_enable', array(
	   'settings' => 'swimming_pool_tagline_enable',
	   'section'   => 'title_tagline',
	   'label'     => __('Enable Site Tagline','swimming-pool'),
	   'type'      => 'checkbox'
	));

	//Theme Options
	$wp_customize->add_panel( 'swimming_pool_panel_area', array(
		'priority' => 10,
		'capability' => 'edit_theme_options',
		'title' => __( 'Theme Options Panel', 'swimming-pool' ),
	) );
	
	// Header Section
	$wp_customize->add_section('swimming_pool_header_section', array(
        'title' => __('Manage Header Section', 'swimming-pool'),
        'priority' => null,
		'panel' => 'swimming_pool_panel_area',
 	));

	$wp_customize->add_setting('swimming_pool_fb_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'swimming_pool_fb_link', array(
	   'settings' => 'swimming_pool_fb_link',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Facebook Link', 'swimming-pool'),
	   'type'      => 'url'
	));

	$wp_customize->add_setting('swimming_pool_twitt_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'swimming_pool_twitt_link', array(
	   'settings' => 'swimming_pool_twitt_link',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Twitter Link', 'swimming-pool'),
	   'type'      => 'url'
	));

	$wp_customize->add_setting('swimming_pool_linked_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'swimming_pool_linked_link', array(
	   'settings' => 'swimming_pool_linked_link',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Linkdin Link', 'swimming-pool'),
	   'type'      => 'url'
	));

	$wp_customize->add_setting('swimming_pool_insta_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'swimming_pool_insta_link', array(
	   'settings' => 'swimming_pool_insta_link',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Instagram Link', 'swimming-pool'),
	   'type'      => 'url'
	));

	$wp_customize->add_setting('swimming_pool_youtube_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'swimming_pool_youtube_link', array(
	   'settings' => 'swimming_pool_youtube_link',
	   'section'   => 'swimming_pool_header_section',
	   'label' => __('Youtube Link', 'swimming-pool'),
	   'type'      => 'url'
	));

	// Home Category Dropdown Section
	$wp_customize->add_section('swimming_pool_one_cols_section',array(
		'title'	=> __('Manage Slider','swimming-pool'),
		'description'	=> __('Select Category from the Dropdowns for slider, Also use the given image dimension (1600 x 850).','swimming-pool'),
		'priority'	=> null,
		'panel' => 'swimming_pool_panel_area'
	));

	// Add a category dropdown Slider Coloumn
	$wp_customize->add_setting( 'swimming_pool_slidersection', array(
		'default'	=> '0',	
		'sanitize_callback'	=> 'absint'
	) );
	$wp_customize->add_control( new Swimming_Pool_Category_Dropdown_Custom_Control( $wp_customize, 'swimming_pool_slidersection', array(
		'section' => 'swimming_pool_one_cols_section',
		'settings'   => 'swimming_pool_slidersection',
	) ) );

	$wp_customize->add_setting('swimming_pool_button_text',array(
		'default' => 'CONTACT US',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'swimming_pool_button_text', array(
	   'settings' => 'swimming_pool_button_text',
	   'section'   => 'swimming_pool_one_cols_section',
	   'label' => __('Add Button Text', 'swimming-pool'),
	   'type'      => 'text'
	));
	
	//Hide Section
	$wp_customize->add_setting('swimming_pool_hide_categorysec',array(
		'default' => false,
		'sanitize_callback' => 'swimming_pool_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 

	$wp_customize->add_control( 'swimming_pool_hide_categorysec', array(
	   'settings' => 'swimming_pool_hide_categorysec',
	   'section'   => 'swimming_pool_one_cols_section',
	   'label'     => __('Check To Enable This Section','swimming-pool'),
	   'type'      => 'checkbox'
	));
	
	// Services Section 
	$wp_customize->add_section('swimming_pool_below_slider_section', array(
		'title'	=> __('Manage Services Section','swimming-pool'),
		'description'	=> __('Select Pages from the dropdown for Services.','swimming-pool'),
		'priority'	=> null,
		'panel' => 'swimming_pool_panel_area',
	));

	$wp_customize->add_setting('swimming_pool_headingtext1',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'swimming_pool_headingtext1', array(
	   'settings' => 'swimming_pool_headingtext1',
	   'section'   => 'swimming_pool_below_slider_section',
	   'label' => __('Add Heading 1', 'swimming-pool'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('swimming_pool_headingtext2',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'swimming_pool_headingtext2', array(
	   'settings' => 'swimming_pool_headingtext2',
	   'section'   => 'swimming_pool_below_slider_section',
	   'label' => __('Add Heading 2', 'swimming-pool'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('swimming_pool_headingtext_para',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'swimming_pool_headingtext_para', array(
	   'settings' => 'swimming_pool_headingtext_para',
	   'section'   => 'swimming_pool_below_slider_section',
	   'label' => __('Add Heading Content', 'swimming-pool'),
	   'type'      => 'text'
	));

	// Add a category dropdown Slider Coloumn
	$wp_customize->add_setting( 'swimming_pool_services_cat', array(
		'default'	=> '0',	
		'sanitize_callback'	=> 'absint'
	) );
	$wp_customize->add_control( new Swimming_Pool_Category_Dropdown_Custom_Control( $wp_customize, 'swimming_pool_services_cat', array(
		'section' => 'swimming_pool_below_slider_section',
		'settings'   => 'swimming_pool_services_cat',
	) ) );

	$wp_customize->add_setting('swimming_pool_disabled_pgboxes',array(
		'default' => false,
		'sanitize_callback' => 'swimming_pool_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));
	
	$wp_customize->add_control( 'swimming_pool_disabled_pgboxes', array(
	   'settings' => 'swimming_pool_disabled_pgboxes',
	   'section'   => 'swimming_pool_below_slider_section',
	   'label'     => __('Check To Enable This Section','swimming-pool'),
	   'type'      => 'checkbox'
	));

	// Footer Section 
	$wp_customize->add_section('swimming_pool_footer', array(
		'title'	=> __('Manage Footer Section','swimming-pool'),
		'priority'	=> null,
		'panel' => 'swimming_pool_panel_area',
	));

	$wp_customize->add_setting('swimming_pool_copyright_line',array(
		'sanitize_callback' => 'sanitize_text_field',
	));	
	$wp_customize->add_control( 'swimming_pool_copyright_line', array(
	   'section' 	=> 'swimming_pool_footer',
	   'label'	 	=> __('Copyright Line','swimming-pool'),
	   'type'    	=> 'text',
	   'priority' 	=> null,
    ));

}
add_action( 'customize_register', 'swimming_pool_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function swimming_pool_customize_preview_js() {
	wp_enqueue_script( 'swimming_pool_customizer', esc_url(get_template_directory_uri()) . '/js/customize-preview.js', array( 'customize-preview' ), '20161510', true );
}
add_action( 'customize_preview_init', 'swimming_pool_customize_preview_js' );